Welcome to ClientVPS Mirrors

Help for package ideamdb
Type: Package
Title: Easy Manipulation of IDEAM's Climatological Data
Version: 0.0.9
Description: Time series plain text conversion and data visualization. It allows to transform IDEAM (Instituto de Hidrologia, Meteorologia y Estudios Ambientales) daily series from plain text to CSV files or data frames in R. Additionally, it is possible to obtain exploratory graphs from times series. IDEAM’s data is freely delivered under formal request through the official web page http://www.ideam.gov.co/solicitud-de-informacion.
License: GPL-2 | GPL-3 [expanded from: GPL (≥ 2)]
Depends: R (≥ 2.10)
Encoding: UTF-8
LazyData: true
RoxygenNote: 6.1.1
Imports: stringr, tidyr, dplyr, ggplot2, utils, graphics
Suggests: knitr, rmarkdown
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2019-03-20 04:29:06 UTC; ees_o
Author: Luz Maria Morales [aut, cre], Edwin Echeverri [aut], Kenneth Roy Cabrera [aut]
Maintainer: Luz Maria Morales <lummoralesgo@unal.edu.co>
Repository: CRAN
Date/Publication: 2019-03-24 19:10:06 UTC

A dataset with fictitious values of no real IDEAM's Stations. The text file keeps IDEAM's text format.

Description

A dataset with fictitious values of no real IDEAM's Stations. The text file keeps IDEAM's text format.

Usage

data(Example_IDEAM)

Format

text file

It is a self-made file. Original data could be freely required through IDEAM's web page. http://www.ideam.gov.co/solicitud-de-informacion

Examples

data(Example_IDEAM)

Create a day by day IDEAM's data serie

Description

Create a data frame with one value by row. The df is available to export as a CSV file

Usage

IdeamLong(file, write = FALSE, outfile = "MatrizIdeamLarga")

Arguments

file

IDEAM file path or file name if it is on the working directory

write

If True a CSV file is returned to the working directory, otherwise only a data frame is shown

outfile

Outfile name that will be saved on the working directory

Value

dataframe or a CSV file

Examples

# Retreive example dataset
Example_IDEAM <- system.file("extdata", "Example_IDEAM", package = "ideamdb")
# Create a temporal file
example.ideam.long <- tempfile()
write.csv(IdeamLong(Example_IDEAM), file = example.ideam.long)
read.csv(example.ideam.long)


Create a matrix with IDEAM's data

Description

Create a data frame that it is available to export as a CSV file

Usage

IdeamWide(file, write = FALSE, outfile = "MatrizIdeamAncha")

Arguments

file

IDEAM file path or file name if it is on the working directory

write

If True a CSV file is returned to the working directory, otherwise only a data frame is shown

outfile

Outfile name that will be saved on the working directory

Value

a data frame or a CSV file

Examples

# Retreive example dataset
Example_IDEAM <- system.file("extdata", "Example_IDEAM", package = "ideamdb")
# Create a temporal file
example.ideam.wide <- tempfile()
write.csv(IdeamWide(Example_IDEAM), file = example.ideam.wide)
read.csv(example.ideam.wide)


Graphical exploratory charts

Description

Create a time series chart and a boxplot of every data sample

Usage

TimeSeries(file, station = "all", variable = "all")

Arguments

file

IDEAM file path or file name if it is on the working directory

station

a single station name or type "all" or "todas" to plot everything

variable

a single variable name or type "all" or "todas" to plot everything only a data frame is shown

Value

time series plot and boxplot for every variable data and station

Examples

Example_IDEAM <- system.file("extdata", "Example_IDEAM", package = "ideamdb")
TimeSeries(Example_IDEAM, station = "LUCERO")
# Print time series chart and boxplots for all variables
# collected in an specific station

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.